@@ -4,7 +4,6 @@
 #include <stdint.h>
 #include <errno.h>
 
-#include <skalibs/posixishard.h>
 #include <skalibs/uint32.h>
 #include <skalibs/allreadwrite.h>
 #include <skalibs/tai.h>
@@ -12,11 +11,13 @@
 #include <skalibs/djbunix.h>
 #include <skalibs/unixmessage.h>
 
-#include <s6/s6-fdholder.h>
+#include <s6/fdholder.h>
 
-int s6_fdholder_getdump (s6_fdholder_t *a, genalloc *g, tain_t const *deadline, tain_t *stamp)
+#include <skalibs/posixishard.h>
+
+int s6_fdholder_getdump (s6_fdholder_t *a, genalloc *g, tain const *deadline, tain *stamp)
 {
-  unixmessage_t m  = { .s = "?", .len = 1, .fds = 0, .nfds = 0 } ;
+  unixmessage m  = { .s = "?", .len = 1, .fds = 0, .nfds = 0 } ;
   uint32_t ntot, n ;
   size_t oldlen = genalloc_len(s6_fdholder_fd_t, g) ;
   unsigned int i = 0 ;
@@ -25,7 +26,7 @@ int s6_fdholder_getdump (s6_fdholder_t *a, genalloc *g, tain_t const *deadline,
   if (!unixmessage_sender_timed_flush(&a->connection.out, deadline, stamp)) return 0 ;
   if (sanitize_read(unixmessage_timed_receive(&a->connection.in, &m, deadline, stamp)) < 0) return 0 ;
   if (!m.len || m.nfds) return (errno = EPROTO, 0) ;
-  if (m.s[0]) return (errno = m.s[0], 0) ;
+  if (m.s[0]) return (errno = (unsigned char)m.s[0], 0) ;
   if (m.len != 9) return (errno = EPROTO, 0) ;
   uint32_unpack_big(m.s + 1, &n) ;
   uint32_unpack_big(m.s + 5, &ntot) ;
