@@ -9,9 +9,9 @@
 #include <skalibs/tai.h>
 #include <skalibs/gensetdyn.h>
 #include <skalibs/textclient.h>
-#include <s6/s6lock.h>
+#include <s6/lock.h>
 
-int s6lock_acquire (s6lock_t *a, uint16_t *u, char const *path, uint32_t options, tain_t const *limit, tain_t const *deadline, tain_t *stamp)
+int s6lock_acquire (s6lock_t *a, uint16_t *u, char const *path, uint32_t options, tain const *limit, tain const *deadline, tain *stamp)
 {
   size_t pathlen = strlen(path) ;
   char tmp[23] = "--<" ;
@@ -35,7 +35,7 @@ int s6lock_acquire (s6lock_t *a, uint16_t *u, char const *path, uint32_t options
     errno = e ;
     return 0 ;
   }
-  *GENSETDYN_P(char, &a->data, i) = EAGAIN ;
+  *GENSETDYN_P(unsigned char, &a->data, i) = EAGAIN ;
   *u = i ;
   return 1 ;
 }
