@@ -5,11 +5,11 @@
 #include <skalibs/uint16.h>
 #include <skalibs/gensetdyn.h>
 #include <skalibs/textclient.h>
-#include <s6/s6lock.h>
+#include <s6/lock.h>
 
-int s6lock_release (s6lock_t *a, uint16_t i, tain_t const *deadline, tain_t *stamp)
+int s6lock_release (s6lock_t *a, uint16_t i, tain const *deadline, tain *stamp)
 {
-  char *p = GENSETDYN_P(char, &a->data, i) ;
+  unsigned char *p = GENSETDYN_P(unsigned char, &a->data, i) ;
   char pack[3] = "-->" ;
   if ((*p != EBUSY) && !error_isagain(*p))
   {
