@@ -2,12 +2,13 @@
 
 #include <errno.h>
 
-#include <skalibs/posixishard.h>
 #include <skalibs/iopause.h>
 
-#include <s6/s6lock.h>
+#include <s6/lock.h>
 
-int s6lock_wait_or (s6lock_t *a, uint16_t const *idlist, unsigned int n, tain_t const *deadline, tain_t *stamp)
+#include <skalibs/posixishard.h>
+
+int s6lock_wait_or (s6lock_t *a, uint16_t const *idlist, unsigned int n, tain const *deadline, tain *stamp)
 {
   iopause_fd x = { -1, IOPAUSE_READ | IOPAUSE_EXCEPT, 0 } ;
   x.fd = s6lock_fd(a) ;
