@@ -1,5 +1,5 @@
 /* ISC license. */
 
-#include <s6/s6lock.h>
+#include <s6/lock.h>
 
 s6lock_t const s6lock_zero = S6LOCK_ZERO ;
