@@ -5,7 +5,7 @@
 #include <skalibs/sgetopt.h>
 #include <skalibs/types.h>
 #include <skalibs/tai.h>
-#include <skalibs/strerr2.h>
+#include <skalibs/strerr.h>
 #include <skalibs/djbunix.h>
 
 #include "s6-svlisten.h"
@@ -19,7 +19,6 @@ int main (int argc, char const *const *argv, char const *const *envp)
   tain deadline, tto ;
   pid_t pid ;
   int spfd ;
-  int e ;
   int wantup = 1, wantready = 0, wantrestart = 0 ;
   uint16_t id ;
   unsigned char upstate, readystate ;
@@ -53,9 +52,10 @@ int main (int argc, char const *const *argv, char const *const *envp)
   s6_svlisten_init(1, argv, &foo, &id, &upstate, &readystate, &deadline) ;
   pid = child_spawn0(argv[1], argv + 1, envp) ;
   if (!pid) strerr_diefu2sys(111, "spawn ", argv[1]) ;
-  if (wantrestart) s6_svlisten_loop(&foo, 0, 1, 1, &deadline, spfd, &s6_svlisten_signal_handler) ;
-  e = s6_svlisten_loop(&foo, wantup, wantready, 1, &deadline, spfd, &s6_svlisten_signal_handler) ;
-  if (e < 0) strerr_dief1x(102, "supervisor died") ;
-  else if (e > 0) strerr_dief2x(1, argv[0], " failed permanently: the finish script exited 125") ;
+  if (wantrestart)
+    if (s6_svlisten_loop(&foo, 0, 1, 1, &deadline, spfd, &s6_svlisten_signal_handler))
+      strerr_dief2x(1, argv[0], " failed permanently or its supervisor died") ;
+  if (s6_svlisten_loop(&foo, wantup, wantready, 1, &deadline, spfd, &s6_svlisten_signal_handler))
+    strerr_dief2x(1, argv[0], " failed permanently or its supervisor died") ;
   return 0 ;
 }
