@@ -8,7 +8,7 @@
 #include <skalibs/bitarray.h>
 #include <skalibs/sig.h>
 #include <skalibs/tai.h>
-#include <skalibs/strerr2.h>
+#include <skalibs/strerr.h>
 
 #include "s6-svlisten.h"
 
@@ -51,7 +51,7 @@ int main (int argc, char const *const *argv)
 
   {
     s6_svlisten_t foo = S6_SVLISTEN_ZERO ;
-    int e ;
+    unsigned int e ;
     uint16_t ids[argc] ;
     unsigned char upstate[bitarray_div8(argc)] ;
     unsigned char readystate[bitarray_div8(argc)] ;
@@ -61,12 +61,10 @@ int main (int argc, char const *const *argv)
     {
       wantup = 1 ;
       e = s6_svlisten_loop(&foo, 0, 0, 0, &deadline, -1, 0) ;
-      if (e < 0) strerr_dief1x(102, "supervisor died") ;
-      else if (e > 0) strerr_dief1x(e, "some services reported permanent failure") ; 
+      if (e) strerr_dief1x(e, "some services reported permanent failure or their supervisor died") ;
     }
     e = s6_svlisten_loop(&foo, wantup, wantready, or, &deadline, -1, 0) ;
-    if (e < 0) strerr_dief1x(102, "supervisor died") ;
-    else if (e > 0) strerr_dief1x(e, "some services reported permanent failure") ; 
+    if (e) strerr_dief1x(e, "some services reported permanent failure or their supervisor died") ; 
   }
   return 0 ;
 }
